@@ -68,12 +68,18 @@ def init_data_tree(indir, legacy_spec0122=False):
         # Header key indicating channel isn't in the format I'm using for tracking files
         chankey = short.upper().replace("1", "+").replace("2", "-")
         for dkey, head_kw in zip(["flats", "data"], ["gain", "observe"]):
+            if dkey == "flats" and chankey == "BB":
+                continue
             for m in range(4):
                 search_keys = (
-                    {"VTF__002": chankey, "VTF_031": m, "DKIST003": head_kw}
+                    {"VTF__002": chankey, "VTF__031": m, "DKIST003": head_kw}
                     if legacy_spec0122
-                    else {"VTF_002": chankey, "VTF__021": m, "DKIST003": head_kw}
+                    else {"VTF__002": chankey, "VTF__021": m, "DKIST003": head_kw}
                 )
                 asdf_file = headers.add_to_asdf(
                     f"{dkey} modstate{m}", search_keys, raw=True
                 )
+        if chankey == "BB":
+            asdf_file = headers.add_to_asdf(
+                "flats modstate0", {"DKIST003": "gain", "VTF__002": chankey}, raw=True
+            )
