@@ -6,7 +6,11 @@ from skimage.transform import AffineTransform, warp
 
 from astropy.io import fits
 
+from dkist.asdf_maker import headers_from_filenames as heads
+from dkist.asdf_maker import references_from_filenames as refs
 from vtfcal.reconstruction.speckle import calc_fried_param, run_speckle
+from vtfcal.test_constants import TEST_DATA_SIZE
+from vtfcal.utils import plotframes
 
 
 def reconstruct(asdf_file):
@@ -32,17 +36,29 @@ def reconstruct(asdf_file):
     )
 
     outdir = asdf_file["support"]["data_dir"]
-    fname = Path(outdir) / f"speckle-output.FITS"
+    fname = Path(outdir) / "speckle-output.FITS"
 
-    logger.warning(
-        "Speckle images do not match size of simulated VTF data - scaling to match."
-    )
-    specframe = warp(
-        specframe,
-        AffineTransform(matrix=np.array([[0.5, 0, 0], [0, 0.5, 0], [0, 0, 1]])).inverse,
-        output_shape=(512, 512),
-        cval=specframe.mean(),
-    )
+    imsize = np.array(specframe.shape)
+    if (imsize != TEST_DATA_SIZE).any():
+        logger.warning(
+            "Speckle images do not match size of simulated VTF data - scaling to match."
+        )
+        scale = TEST_DATA_SIZE / imsize
+        specframe = warp(
+            specframe,
+            AffineTransform(
+                matrix=np.array([[scale, 0, 0], [0, scale, 0], [0, 0, 1]])
+            ).inverse,
+            output_shape=(TEST_DATA_SIZE),
+            cval=specframe.mean(),
+        )
     fits.writeto(fname, specframe, overwrite=True)
+    headers = np.array(heads([specframe]))
+    asdf_file["support"]["speckle"] = refs(specframe, headers, 1)
+    asdf_file.update()
+
+    plotframes(
+        asdf_file, [("speckle", "Speckle-reconstructed broadband image",)], "speckle",
+    )
 
     return asdf_file
