@@ -2,13 +2,14 @@ from pathlib import Path
 
 import numpy as np
 
-# TODO replace these with paths from config
-PATH = Path.home() / "DKIST" / "vtfcal" / "vtfcal"
-DATA = PATH / "data"
-TEST_DATA_SIZE = (512, 512)
-# TEST_PIXEL = (800, 800)
+# TODO Move all of this to utils
+
+TEST_DATA_SIZE = (1024, 1024)
 TEST_PIXEL0 = (125, 50)
-rot = 9
+
+## This will just return the unrotated test pixel
+## TODO TEST_PIXEL should be a dict that uses the actual per-channel rotation values
+rot = 0
 c = np.cos(np.deg2rad(rot))
 s = np.sin(np.deg2rad(rot))
 rm = np.array([[c, -s, 0], [s, c, 0]])
@@ -20,5 +21,6 @@ TEST_PIXEL = (
     int((rm[0, 0] * TEST_PIXEL0[0]) + (rm[0, 1] * TEST_PIXEL0[1]) + rm[0, 2]),
     int((rm[1, 0] * TEST_PIXEL0[0]) + (rm[1, 1] * TEST_PIXEL0[1]) + rm[1, 2]),
 )
+
 TEST_WL_IDX = 10
 RADIUS = 32
