@@ -14,9 +14,17 @@ from dkist.asdf_maker import headers_from_filenames as heads
 from dkist.asdf_maker import references_from_filenames as refs
 
 
+def get_wavelength_step(filepath):
+    logger = logging.getLogger(__name__)
+    logger.setLevel("INFO")
+    header = fits.getheader(filepath)
+    l = header["VTF__014"]
+    return int(l)
+
+
 def get_modstate(filepath):
     header = fits.getheader(filepath)
-    m = header["VTF__031"]
+    m = header["VTF__021"]
     return f"modstate{int(m)}"
 
 
@@ -84,37 +92,32 @@ def average_by_wavelength(asdf_file, filekey):
             '- "mode" keyword should be either "broadband" or "narrowband".'
         )
 
-    raw_dir = asdf_file["raw"]["data_dir"]
-    logger.debug(f"{raw_dir}")
     outdir = asdf_file["support"]["data_dir"]
     logger.debug(f"{outdir}")
 
-    # This is not especially robust
-    prefix = filekey[:-1]
-    logger.debug(f"Searching for raw {prefix} files in {raw_dir}")
-    fnames = list(Path(raw_dir).rglob(f"{prefix}*.FITS"))
-    logger.debug(f"Found the following raw {prefix} files: {[str(f) for f in fnames]}")
+    ## TODO I need to double-check the method here and see how much of this can just be done purely on header keywords
 
-    fnames = sorted(fnames, key=get_modstate)
-    filegroups = groupby(fnames, key=get_modstate)
-    for modstate, files in filegroups:
-        logger.debug(f"{modstate} {files}")
+    modstates = (
+        ["modstate0"]
+        if asdf_file["mode"] == "broadband"
+        else ["modstate0", "modstate1", "modstate2", "modstate3"]
+    )
+    for modstate in modstates:
+        filelist = [str(f.fileuri) for f in asdf_file["raw"][f"{filekey} {modstate}"]]
         averaged_frames = []
-        filelist = list(files)
-        modfiles = refs(filelist, np.array(heads(filelist)), len(filelist))
-        # TODO rewrite the above as a dict comprehension using the walrus operator (requires py3.8)
-        # files_by_modstate = {modstate: refs(flist:=list(files), np.array(heads(flist)), len(flist)) for modstate, files in groupby(sorted(fnames, key=get_modstate), key=get_modstate)}
 
-        fnames = groupby(modfiles, key=lambda x: split(x.fileuri)[-1])
-        for out_fname, files in fnames:
+        # group by wavelength
+        fnames = groupby(filelist, key=get_wavelength_step)
+        for l, files in fnames:
+            out_fname = f"{filekey}_l{l:02}{modstate}.FITS"
             # TODO: consider using ImageFileCollection here instead
             frames = [
-                ccdproc.CCDData.read(f.fileuri, format="fits", unit="adu")
+                ccdproc.CCDData.read(f, format="fits", unit="adu")
                 for f in list(files)
             ]
             outfile = join(outdir, modstate, out_fname)
             logger.debug(f"Averaging {filekey} to {outfile}")
-            ccdproc.combine(frames, output_file=outfile)
+            outimg = ccdproc.combine(frames, output_file=outfile)
             averaged_frames.append(outfile)
         averaged_frames.sort()
         logger.debug(averaged_frames)
@@ -200,7 +203,7 @@ class HeaderTracker:
         support_fnames = list(supportpath.rglob("*.FITS"))
 
         self.raw_headers = dict(zip(raw_fnames, heads(raw_fnames)))
-        self.support_frames = dict(zip(support_fnames, heads(support_fnames)))
+        self.support_headers = dict(zip(support_fnames, heads(support_fnames)))
 
     def files_with_keyword(self, keyword, value, raw):
         logger = logging.getLogger(__name__)
@@ -221,6 +224,7 @@ class HeaderTracker:
         logger.setLevel("INFO")
         logger.debug(f"Finding files with keywords {kw_dict}")
         keybase = "raw" if raw else "support"
+        headers = self.raw_headers if raw else self.support_headers
         allfiles = None
         for keyword in kw_dict.keys():
             files = self.files_with_keyword(keyword, kw_dict[keyword], raw)
@@ -233,7 +237,7 @@ class HeaderTracker:
 
         logger.debug(f"Selected {len(allfiles)} files")
         self.asdf_file[keybase][dkey] = refs(
-            allfiles, np.array(heads(allfiles)), len(allfiles)
+            allfiles, np.array([headers[f] for f in allfiles]), len(allfiles)
         )
 
         try:
